==> providence-core-0.3.16-sources.jar: net/morimekta/providence/descriptor/PDeclaredDescriptor.java <==
/*
 * Copyright 2015-2016 Providence Authors
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package net.morimekta.providence.descriptor;

import net.morimekta.providence.PBuilder;

import javax.annotation.Nonnull;

/**
 * Descriptor for a declared type. A declared type is a value type that is
 * derived from a thrift definition.
 */
public abstract class PDeclaredDescriptor<T> implements PDescriptor {
    private final String programName;
    private final String name;

    protected PDeclaredDescriptor(@Nonnull String programName, @Nonnull String name) {
        this.programName = programName;
        this.name = name;
    }

    @Nonnull
    @Override
    public final String getProgramName() {
        return programName;
    }

    @Nonnull
    @Override
    public final String getName() {
        return name;
    }

    @Nonnull
    @Override
    public final String getQualifiedName(String programContext) {
        if (!this.programName.equals(programContext)) {
            return getProgramName() + "." + getName();
        }
        return getName();
    }

    @Override
    public String toString() {
        return getQualifiedName();
    }

    /**
     * Get the builder for the given declared type.
     *
     * @return The type specific builder provider.
     */
    public abstract PBuilder<T> builder();
}

==> providence-core-0.3.92-sources.jar: net/morimekta/providence/descriptor/PDeclaredDescriptor.java <==
/*
 * Copyright 2015-2016 Providence Authors
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package net.morimekta.providence.descriptor;

import net.morimekta.providence.PBuilder;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

/**
 * Descriptor for a declared type. A declared type is a value type that is
 * derived from a thrift definition.
 */
public abstract class PDeclaredDescriptor<T> implements PDescriptor {
    private final String programName;
    private final String name;

    protected PDeclaredDescriptor(@Nonnull String programName, @Nonnull String name) {
        this.programName = programName;
        this.name = name;
    }

    @Nonnull
    @Override
    public final String getProgramName() {
        return programName;
    }

    @Nonnull
    @Override
    public final String getName() {
        return name;
    }

    @Nonnull
    @Override
    public final String getQualifiedName(String programContext) {
        if (!this.programName.equals(programContext)) {
            return getProgramName() + "." + getName();
        }
        return getName();
    }

    @Nullable
    @Override
    public T getDefaultValue() {
        // Declared value types currently cannot have default values defined by the descriptor.
        return null;
    }

    @Override
    public String toString() {
        return getQualifiedName();
    }

    /**
     * Get the builder for the given declared type.
     *
     * @return The type specific builder provider.
     */
    public abstract PBuilder<T> builder();
}
